#### Please select the sections that you would like to print

Select All
Case Information
Party
Disposition Events
Events and Hearings
Print

# Case Information

18CV001704 | Loving Life Real Estate, LLC vs Jose Saldana et al

Case Number
18CV001704

Court
Superior Court of Napa - Civil

File Date
12/17/2018

Case Type
Unlawful Detainer Residential Limited (32) - under 10,000

Case Status
Inactive

# Party

Plaintiff
Loving Life Real Estate, LLC

Active Attorneys

Lead Attorney
Myers, Alexander James

Retained

Work Phone
707-257-1185

Attorney
LaPorte, Donna Lyn

Retained

Work Phone
9499554356

Defendant
Saldana, Jose

Address

1413 Spring ST
St Helena CA 94574

Active Attorneys

Pro Se

Defendant
Saldana, Amelia

Address

1461 Main ST
UNIT 631
St Helena CA 94574-7427

Active Attorneys

Pro Se

Defendant
Botto, Jorge

Address

1413 Springs ST
St Helena CA 94574

Active Attorneys

Pro Se

Attorney
Imperiale, James Thomas

Retained

Work Phone
6196309615

Claimant
Olivera, Manuel

Address

1413 Spring ST
St Helena CA 94574

Claimant (Participant)
Aguayo, Lorenzo

Address

1413 Spring ST
St Helena CA 94574

Claimant (Participant)
Garcia, Cristian Martin

Address

1413 Spring ST
St Helena CA 94574

Claimant (Participant)
Arias Ramirez, Abelardo Javier

Address

1413 Spring ST
St Helena CA 94574

Claimant (Participant)
Saldana, J. Manuel

Address

1413 Spring ST
St Helena CA 94574

# Disposition Events

02/08/2019 Judgment

Judgment Type
Judgment - Court Finding

Party
| Names: Loving Life Real Estate, LLC Saldana, Jose Saldana, Amelia

02/28/2019 Judgment

Judgment Type
Dismissal - No ADR

Party
| Name: Olivera, Manuel

# Events and Hearings

- 12/17/2018 Civil Case Cover Sheet

- 12/17/2018 Complaint-Unlawful Detainer (Limited): Up to $10K

- 12/17/2018 Summons: Issued and Filed

- 12/17/2018 Notice of Hearing Court

- 12/17/2018 Unlawful Detainer - Defendant's Notice

- 12/28/2018 Motion

  Comment
  NOTICE OF MOTION T0 STRIKE AND MOTION T0 STRIKE COMPLAINT; MEMORANDUM OF POINTS AND AUTHORITIES

- 01/03/2019 Complaint: Amended

- ﻿

  01/18/2019 Motion to Strike

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

- 01/18/2019 Answer (Limited): Up to $10K

  Comment
  Answer/Response/Denial/Demurrer - First Appearance

- 01/18/2019 Minute Order

- 01/23/2019 Proof of Service

- 01/23/2019 Request

  Comment
  to Set Case for Trial

- 01/23/2019 Notice of Hearing Court

- ﻿

  02/08/2019 Court Trial: Short Cause

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

- 02/08/2019 Judgment

- 02/08/2019 UD: Judgment Against All Def Within 60 Days

- 02/08/2019 Minute Order

- 02/11/2019 Writ (Issued)

- ﻿

  02/15/2019 OSC: Court's Motion to Dismiss

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated

- ﻿

  02/21/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Cancel Reason
  Vacated

- 02/25/2019 Claim of Right to Possession

- 02/25/2019 Notice of Hearing Court

- ﻿

  02/27/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Result
  Heard

- 02/27/2019 Application: Ex Parte (Fee Applies)

  Comment
  Ex Parte Application for Order Shortening Time to Advance Hearing on Claim of Right to Possession; Memorandum of Points and Authorities; Declaration of Alexander Myers

- 02/27/2019 Declaration

  Comment
  Declaration Re: Notice for Ex Parte Hearing

- 02/27/2019 Order

  Comment
  Order After Hearing

- 02/27/2019 Claim of Right to Possession

- 02/27/2019 Notice of Hearing

- 02/27/2019 Motion: Peremptory Challenge CCP 170.6

  Judicial Officer
  Wood, Victoria

  Comment
  DENIED BY VW

- 02/27/2019 Minute Order

- 02/27/2019 Minute Order: Amended

- 02/28/2019 Fee Waiver Granted

- 02/28/2019 Request: Dismissal

- ﻿

  03/01/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated

  Comment
  CLAIM OF RIGHT TO POSSESSION (Manuel Olivera)

- ﻿

  03/04/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Result
  Heard

  Comment
  Defendant's Application for Motion to Vacate Judgment

- ﻿

  03/04/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  1:30 PM

  Result
  Heard

  Comment
  CLAIM OF RIGHT TO POSSESSION (Jorge Botto)

- 03/04/2019 Substitution: Attorney

- 03/04/2019 Application: Ex Parte (Fee Applies)

  Comment
  DEFENDANT'S EX PARTE APPLICATION AND MOTION T0 SET ASIDE, VACATE VOID JUDGMENT ON FEBRUARY 8, 2019; VACATE AND 0R RECALL THE WRIT; MEMORANDUM OF POINTS AND AUTHORITIES AND DECLARATION

- 03/04/2019 Declaration

  Comment
  DEFENDANT'S DECLARATION IN SUPPORT OF HER EX PARTE APPLICATION TO VACATE VOID JUDGMENT

- 03/04/2019 Substitution: Attorney

- 03/04/2019 Notice

  Comment
  LIMITED SCOPE

- 03/04/2019 Minute Order

- 03/06/2019 Exhibit List (Court)

- 03/06/2019 Minute Order

- ﻿

  03/15/2019 Court Trial: Short Cause

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  to be heard at 9:30am TE: 1 hour

- 03/15/2019 Substitution: Attorney

- 03/15/2019 Notice: Stay of Proceedings

- 03/15/2019 Minute Order

- 03/15/2019 Notice of Hearing Court

- ﻿

  03/22/2019 Court Trial: Short Cause

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Review stay--to be heard at 9:00 a.m.

- 03/22/2019 Minute Order

- 04/15/2019 Notice

  Comment
  Notice of Association of Counsel

- 05/07/2019 Order

  Comment
  Order Adopting Report and Reccommendation to Remand Case to State Court

- 05/07/2019 Notice of Hearing Court

- 05/07/2019 Request

  Comment
  Request to Set Case for Trial

- 05/07/2019 Notice of Hearing Court

- 05/17/2019 Request

  Comment
  Request to Set Case for Trial

- 05/21/2019 Returned or Undeliverable Mail

- 05/21/2019 Notice of Hearing Court

- 05/23/2019 Notice

  Comment
  Notice of Limited Scope Representation

- ﻿

  05/24/2019 Court Trial: Short Cause

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

- 05/24/2019 Advance Jury Fee (Nonrefundable)

- 05/24/2019 Exhibit List (Court)

- 05/24/2019 Minute Order

- 05/28/2019 Judgment

  Comment
  After Court for Possession Only

- 06/04/2019 Judgment

  Comment
  Amended Judgment (main house)

- 06/04/2019 Judgment

  Comment
  Amended Judgment (rear unit)

- 06/06/2019 Writ (Issued)

  Comment
  County of Napa (Main House)

- 06/06/2019 Writ (Issued)

  Comment
  County of Napa (Rear Unit)

- 06/07/2019 Proof of Service

  Comment
  of Ex parte hearing

- 06/07/2019 Application: Ex Parte (Fee Applies)

  Comment
  Defendant Jorge Botto's ex parte application and motion to set aside Judgment; Memorandum of poin and authorities to set aside judgment in the limited unlawful detainer proceedings

- 06/07/2019 Declaration

  Comment
  od Cynthia Brown; in support of defendant Jorge Botto's request for new trial

- 06/07/2019 Declaration

  Comment
  Jose Botto declaration in support

- 06/07/2019 Declaration

  Comment
  Jose Saldana's Jr.'s declaration in support

- 06/07/2019 Notice

  Comment
  defendants request for judicial notice

- ﻿

  06/10/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Result
  Heard

- 06/10/2019 Notice

  Comment
  Notice of Limited Scope Representation

- 06/10/2019 Minute Order

- 06/12/2019 Claim of Right to Possession

  Comment
  Post-Judgment

- 06/12/2019 Notice of Hearing Court

- 06/12/2019 Notice of Hearing Court

- 06/17/2019 Claim of Right to Possession

- 06/17/2019 Notice of Hearing Court

- ﻿

  06/18/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Result
  Continued Court's Motion: Hearing

  Comment
  Plaintiff's Application

- ﻿

  06/18/2019 Exparte Application

  Judicial Officer
  Wood, Victoria

  Hearing Time
  11:30 AM

  Result
  Continued Party's Motion: Hearing

  Comment
  Defendant Amelia Saldana's Application

- 06/18/2019 Application: Ex Parte (Fee Applies)

- 06/18/2019 Declaration

  Comment
  in support of Ex parte motion for order shortening time

- 06/18/2019 Declaration

  Comment
  Re: Notice for ex parte hearing

- 06/18/2019 Application: Ex Parte (Fee Applies)

  Comment
  EMERGENCY EX PARTE APPLICATION MOTION FOR STAY REQUESTED; IMMEDIATE RELIEF REQUESTED STAYING OF EXECUTION OF THE WRIT OF POSSESSION DURING PENDENCY OF THE APPEAL

- 06/18/2019 Request

  Comment
  DEFENDANT'S EX PARTE APPLICATION FOR JUDICIAL NOTICE IN SUPPORT OF STAY

- 06/18/2019 Notice

  Comment
  LIMITED SCOPE REPRESENTATION

- 06/18/2019 Pleading: Amended

  Comment
  Defendant's Amended Ex Parte Application for Judicial Notice in Support of Stay

- 06/18/2019 Notice of Hearing Court

  Comment
  Lorenzo Aguayo

- 06/18/2019 Notice of Hearing Court

  Comment
  Cristian Martin Garcia

- 06/18/2019 Minute Order

- ﻿

  06/21/2019 OSC/Status DLR

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated

- 06/24/2019 Opposition or Objections

  Comment
  PLAINTIFF'S MEMORANDUM IN OPPOSITION TO DEFENDANT'S AMENDED "EMERGENCY EX PARTE APPLICATION MOTION FOR STAY REQUESTED; IMMEDIATE RELIEF REQUESTED STAYING OF EXECUTION OF THE WRIT OF POSSESSION DURING PENDENCY OF THE APPEAL"

- 06/27/2019 Notice

  Comment
  Notice of limited scope representation

- ﻿

  06/28/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  CLAIM OF RIGHT TO POSSESSION: Lorenzo Aguayo

- ﻿

  06/28/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Claim of Right to Possession: Cristian Martin Garcia

- ﻿

  06/28/2019 Motion

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated

- ﻿

  06/28/2019 Motion

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Stay of Execution: Amelia Saldana

- 06/28/2019 Notice

  Comment
  notice of limited scope representation

- 06/28/2019 Notice

  Comment
  Notice of limited scope representation

- 06/28/2019 Notice

  Comment
  Notice of limited scope representation AMENDED

- 06/28/2019 Minute Order

- 07/02/2019 Claim of Right to Possession

- 07/02/2019 Notice of Hearing Court

- 07/03/2019 Claim of Right to Possession

- 07/03/2019 Notice of Hearing Court

- 07/03/2019 Fee Waiver Denied

- 07/03/2019 Notice of Hearing Court

- 07/05/2019 Request

  Comment
  Request for Hearing Date Change

- 07/08/2019 Notice of Hearing Court

- ﻿

  07/09/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Claim of Right to Possession As to: Abelardo Javier Arias Ramirez

- ﻿

  07/09/2019 Fee Waiver Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Abelardo Javier Arias Ramirez

- 07/09/2019 Minute Order

- 07/10/2019 Order

  Comment
  Order on Court Fee Waiver After Hearing

- 07/17/2019 Notice

  Comment
  Notice of limited scope representation

- ﻿

  07/18/2019 Other Hearing

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Result
  Heard

  Comment
  Claim of Right to Possession As to: J Manuel Saldana

- 07/18/2019 Minute Order

- 07/18/2019 Notice

  Comment
  Notice of Stay of Proceedings

- 08/05/2019 CSB: Referral

  Comment
  Abelardo Javier Arias Ramirez

- 08/08/2019 Writ (Filed)

  Comment
  Rear Unit

- 08/08/2019 Writ (Filed)

  Comment
  Main House

- 08/08/2019 Writ (Filed)

- ﻿

  09/17/2019 OSC/Status DLR

  Judicial Officer
  Wood, Victoria

  Hearing Time
  8:30 AM

  Cancel Reason
  Vacated

- 12/17/2019 Proof of Service